Package 'statsapps'

Title: Interactive 'Shiny' Apps for Building Statistical Intuition
Description: Provides interactive 'Shiny' applications for building intuition in statistics and data science. The apps run locally and use visualization, simulation, and repeated sampling to illustrate topics such as probability distributions, permutation tests, analysis of variance, linear regression, and sums of squares.
Authors: Vikram B. Baliga [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-9367-8974>)
Maintainer: Vikram B. Baliga <[email protected]>
License: MIT + file LICENSE
Version: 0.1.0
Built: 2026-07-23 15:59:10 UTC
Source: https://github.com/cran/statsapps

Help Index


Launch the one-way ANOVA simulator

Description

Opens an interactive Shiny app for exploring how group means, within-group variation, and sample size affect a one-way ANOVA.

Usage

run_anova_app(...)

Arguments

...

Optional arguments passed to shiny::runApp(). By default, statsapps opens apps in the system default web browser using launch.browser = TRUE. Use launch.browser = FALSE to disable this behavior.

Details

All data are simulated in R via rnorm().

Value

run_anova_app() opens the Shiny app locally.

Examples

run_anova_app()

Launch the probability distributions app

Description

Opens an interactive Shiny app for exploring common probability distributions used in BIOL 300.

Usage

run_distributions_app(...)

Arguments

...

Optional arguments passed to shiny::runApp(). By default, statsapps opens apps in the system default web browser using launch.browser = TRUE. Use launch.browser = FALSE to disable this behavior.

Details

All data were simulated and don't come from a specific study.

Value

run_distributions_app() opens the Shiny app locally.

Examples

run_distributions_app()

Launch the simple linear regression app

Description

Opens an interactive Shiny app for exploring how the slope and intercept of a linear model affect fitted values and residuals.

Usage

run_linear_reg_app(...)

Arguments

...

Optional arguments passed to shiny::runApp(). By default, statsapps opens apps in the system default web browser using launch.browser = TRUE. Use launch.browser = FALSE to disable this behavior.

Details

All data were simulated and don't come from a specific study.

Value

run_linear_reg_app() opens the Shiny app locally.

Examples

run_linear_reg_app()

Launch the permutation test app

Description

run_permutation_app() opens an interactive Shiny app that demonstrates how repeated random reassignment of observations can be used to build a null distribution for a two-sample permutation test.

Usage

run_permutation_app(...)

Arguments

...

Optional arguments passed to shiny::runApp(). By default, statsapps opens apps in the system default web browser using launch.browser = TRUE. Use launch.browser = FALSE to disable this behavior.

Details

The app uses data on time to mating in female sagebrush crickets from Johnson et al. (1999), as presented in The Analysis of Biological Data by Whitlock and Schluter.

Value

run_permutation_app() opens the Shiny app locally.

References

Johnson, J. C., T. M. Ivy, and S. K. Sakaluk. 1999. Female remating propensity contingent on sexual cannibalism in sagebrush crickets, Cyphoderris strepitans: a mechanism of cryptic female choice. Behavioral Ecology 10: 227-233.

Whitlock, M. C., and D. Schluter. 2020. The Analysis of Biological Data. 3rd ed. W. H. Freeman and Company.

Examples

run_permutation_app()

Launch the sums of squares app

Description

Opens an interactive Shiny app for exploring how total variation can be partitioned into group-level and within-group components in one-way ANOVA.

Usage

run_sums_squares_app(...)

Arguments

...

Optional arguments passed to shiny::runApp(). By default, statsapps opens apps in the system default web browser using launch.browser = TRUE. Use launch.browser = FALSE to disable this behavior.

Value

run_sums_squares_app() opens the Shiny app locally.

Examples

run_sums_squares_app()